@@ -1,15 +1,15 @@
+#$Id$
 use v5.10;
 package REST::Neo4p::Agent::Mojo::UserAgent;
 use base qw/Mojo::UserAgent REST::Neo4p::Agent/;
 use REST::Neo4p::Exceptions;
-use MIME::Base64;
 use Carp qw/carp/;
 use HTTP::Response;
 use strict;
 use warnings;
 
 BEGIN {
-  $REST::Neo4p::Agent::Mojo::UserAgent::VERSION = '0.4000';
+  $REST::Neo4p::Agent::Mojo::UserAgent::VERSION = 0.2252;
 }
 
 our @default_headers;
@@ -29,13 +29,6 @@ sub credentials {
   my ($srv, $realm, $user, $pwd) = @_;
   $self->{_user} = $user;
   $self->{_pwd} = $pwd;
-  $self->{_userinfo} = "$user:$pwd";
-  $self->{_realm} = $realm;
-  $self->on(start => sub {
-	      my ($ua,$tx) = @_;
-	      $tx->req->url->userinfo($ua->{_userinfo})
-		unless ($tx->req->url->userinfo)
-	    });
   return;
 }
 
@@ -64,12 +57,13 @@ sub http_response {
   my ($tx) = @_;
   # kludge : if 400 error, pull the tmp file content back into response
   # body 
-  if (!defined $tx->res->code) {
-      $tx->res->code(598) if $tx->res->error;
-  }
-  elsif (($tx->res->code =~ /^4[0-9][0-9]/) && $tx->res->content->asset->is_file ) {
+  if ($tx->res->is_status_class(400) && $tx->res->content->asset->is_file ) {
+    $DB::single=1;
     $tx->res->body($tx->res->content->asset->slurp);
   }
+  unless (defined $tx->res->code) {
+      $tx->res->code(598) if $tx->res->error;
+  }
   my $resp = HTTP::Response->new(
     $tx->res->code,
     $tx->res->message // $tx->res->default_message // $tx->res->error,
@@ -93,7 +87,10 @@ sub _do {
   my ($tx, $content, $content_file);
   # neo4j wants to redirect .../data to .../data/
   # and mojo doesn't want to redirect at all...
-  $self->max_redirects || $self->max_redirects(2);
+  $self->max_redirects || $self->max_redirects(2); 
+  if (length($self->{_user}) && length($self->{_pwd})) {
+    $url =~ s|(https?://)|${1}$$self{_user}:$$self{_pwd}@|;
+  }
   given ($rq) {
     when (/get|delete/i) {
       $tx = $self->build_tx($rq => $url => { @{$self->{_default_headers}} });
