@@ -1,4 +1,4 @@
-#$Id: Query.pm 354 2014-02-17 05:22:50Z maj $
+#$Id: Query.pm 427 2014-05-13 19:47:26Z maj $
 use v5.10;
 package REST::Neo4p::Query;
 use REST::Neo4p::Path;
@@ -11,7 +11,7 @@ use strict;
 use warnings;
 no warnings qw(once);
 BEGIN {
-  $REST::Neo4p::Query::VERSION = '0.2242';
+  $REST::Neo4p::Query::VERSION = '0.2252';
 }
 
 #my $BUFSIZE = 4096;
@@ -69,6 +69,7 @@ sub execute {
      );
   }
   eval {
+    use experimental qw/smartmatch/;
     given ($endpt) {
       when (/cypher/) {
 	$agent->$endpt(
@@ -143,6 +144,7 @@ sub execute {
   }
   $self->{_iterator} = 
     sub {
+      use experimental qw/smartmatch/;
       return unless defined $self->tmpf;
       my $row;
       my ($token_type, @data) = @{$jsonr->get_token};
@@ -208,6 +210,7 @@ sub params { shift->{_params} }
 
 sub _response_entity {
   my ($resp) = @_;
+  use experimental qw/smartmatch/;
   if ( ref($resp) eq '' ) { #handle arrays of barewords
     return 'bareword';
   }
@@ -235,6 +238,7 @@ sub _response_entity {
 }
 
 sub _prepare_response {
+  use experimental qw/smartmatch/;
   my $self = shift;
   if (-z $self->tmpf->filename) {
     REST::Neo4p::EmptyQueryResponseException->throw("Server response body is zero length\n");
@@ -355,6 +359,7 @@ sub _prepare_response {
 sub _process_row {
   my $self = shift;
   my ($row) = @_;
+  use experimental qw/smartmatch/;
   my @ret;
   foreach my $elt (@$row) {
     given ($elt) {
@@ -492,11 +497,11 @@ Relationships.
 
 =head2 Transactions
 
-See L<REST::Neo4p/Transaction Support (Neo4p Server Version 2 only)>.
+See L<REST::Neo4p/Transaction Support (Neo4j Server Version 2 only)>.
 
 NOTE: Rows returned from the Neo4j transaction endpoint are not
 completely specified database objects (see
-L<http://docs.neo4j.org/chunked/2.0.0-RC1/rest-api-transactional.html>). Fetches
+L<Neo4j docs|http://docs.neo4j.org/chunked/stable/rest-api-transactional.html>). Fetches
 on transactional queries will return an array of simple Perl
 structures (hashes and arrays) that correspond to the row as returned
 in JSON by the server, rather than as REST::Neo4p objects. This is
@@ -598,7 +603,7 @@ Get the Cypher statement associated with the query object.
 
 =head1 SEE ALSO
 
-L<REST::Neo4p>, L<REST::Neo4p::Path>, L<REST::Neo4p::Agent>.
+L<DBD::Neo4p>, L<REST::Neo4p>, L<REST::Neo4p::Path>, L<REST::Neo4p::Agent>.
 
 =head1 AUTHOR
 
