@@ -1,4 +1,4 @@
-#$Id: Schema.pm 354 2014-02-17 05:22:50Z maj $
+#$Id: Schema.pm 427 2014-05-13 19:47:26Z maj $
 use v5.10;
 package REST::Neo4p::Schema;
 use REST::Neo4p::Exceptions;
@@ -7,7 +7,7 @@ use strict;
 use warnings;
 
 BEGIN {
-  $REST::Neo4p::Schema::VERSION = '0.2242';
+  $REST::Neo4p::Schema::VERSION = '0.2252';
 }
 
 #require 'REST::Neo4p';
@@ -177,7 +177,7 @@ REST::Neo4p::Schema - Label-based indexes and constraints
 
 =head1 DESCRIPTION
 
-L<http://neo4j.org|Neo4j> v2.0 provides a way to schematize the graph
+L<Neo4j|http://neo4j.org> v2.0 provides a way to schematize the graph
 on the basis of node labels, associated indexes, and property
 uniqueness constraints. C<REST::Neo4p::Schema> allows access to this
 system via the Neo4j REST API. Use a C<Schema> object to create, list,
